### Hermes Subsribe

    查询分类
    获取各分类下的商品
    检查商品库存
    定时检查，通知库存变更

## 使用方式

```python
    import hermes

    app = hermes.App()
    #获取分类
    app.categories_list()
    #获取分类下的商品
    app.products(categories=['PRECOLLECTIONPE17'])
    #获取全部商品
    app.products()
    #在终端以表格的方式显示商品信息
    # app.display()
    #把商品写到csv文件
    # app.writeCSV()    

    # H079081CCAB
    #检查 美国商店的库存
    # app.has_stock('H079081CCAB', locale='us_en')
    # app.has_stock('H077763CKS3')


    #定时订阅,每隔60秒检查一次
    app.watch("H077763CKS3",60)
```